pygame.locals — Pygame v1.9.4.dev0 documentation

##### pygame documentation | Pygame Home || Help Contents || Reference Index Color | cursors | display | draw | event | font | image | joystick | key | locals | mask | mixer | mouse | Rect | Surface | sprite | time | transform | BufferProxy | freetype | gfxdraw | midi | Overlay | PixelArray | pixelcopy | sndarray | surfarray | camera | cdrom | examples | math | music | pygame | scrap | tests | version

`pygame.locals`
  pygame constants

  This module contains various constants used by pygame. It's contents are automatically placed in the pygame module namespace. However, an application can use `pygame.locals`pygame constants to include only the pygame constants with a 'from `pygame.locals`pygame constants import *'.

  Detailed descriptions of the various constants are found throughout the pygame documentation. `pygame.display.set_mode()`Initialize a window or screen for display flags like `HWSURFACE` are found in the Display section. Event types are explained in the Event section. Keyboard `K_` constants relating to the key attribute of a `KEYDOWN` or `KEYUP` event are listed in the Key section. Also found there are the various `MOD_` key modifiers. Finally, `TIMER_RESOLUTION` is defined in Time.